import React, { useReducer } from 'react';
import PropTypes from 'prop-types';
import { motion } from 'framer-motion';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var NestedNav = function NestedNav(_ref) {
  var menus = _ref.menus;
  var active = {
    title: menus.title,
    id: menus.id
  };
  var initialState = {
    active: active,
    previous: [],
    previousState: {
      active: active,
      previous: []
    }
  };

  var reducer = function reducer(state, action) {
    switch (action.type) {
      case 'forward':
        {
          var previous = [].concat(state.previous, [state.active]);

          var previousState = _extends({}, state);

          delete previousState.previousState;
          return {
            active: action.payload,
            previous: previous,
            previousState: previousState
          };
        }

      case 'back':
        {
          var _active = [].concat(state.previous)[state.previous.length - 1];

          var _previous = [].concat(state.previous);

          _previous.pop();

          var _previousState = _extends({}, state);

          delete _previousState.previousState;
          return {
            active: _active,
            previous: _previous,
            previousState: _previousState
          };
        }

      default:
        throw new Error();
    }
  };

  var _useReducer = useReducer(reducer, initialState),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  var Menu = function Menu(_ref2) {
    var menu = _ref2.menu;

    if (!menu) {
      return null;
    }

    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(motion.ul, {
      className: "menu",
      style: {
        position: 'absolute',
        top: 0,
        left: 0,
        width: '100%',
        bottom: 0,
        listStyle: 'none',
        margin: 0,
        padding: 0
      },
      transition: {
        type: 'tween'
      },
      animate: menu.id === state.active.id ? 'active' : state.previous.find(function (m) {
        return m.id === menu.id;
      }) ? 'previous' : 'inactive',
      initial: menu.id === state.previousState.active.id ? 'active' : state.previousState.previous.find(function (m) {
        return m.id === menu.id;
      }) ? 'previous' : 'inactive',
      variants: {
        active: {
          x: 0
        },
        inactive: {
          x: '100%'
        },
        previous: {
          x: '-100%'
        }
      }
    }, menu.items.map(function (_ref3, i) {
      var text = _ref3.text,
          link = _ref3.link,
          subMenu = _ref3.menu;
      return /*#__PURE__*/React.createElement("li", {
        className: "menu-item",
        key: i
      }, !subMenu ? /*#__PURE__*/React.createElement("a", {
        className: "menu-item-link",
        href: link
      }, text) : /*#__PURE__*/React.createElement("button", {
        className: "menu-item-link menu-item-button",
        onClick: function onClick() {
          return dispatch({
            type: 'forward',
            payload: {
              title: subMenu.title,
              id: subMenu.id
            }
          });
        }
      }, text));
    })), /*#__PURE__*/React.createElement(React.Fragment, null, menu.items.map(function (_ref4, i) {
      var menu = _ref4.menu;
      return /*#__PURE__*/React.createElement(Menu, {
        key: i,
        menu: menu
      });
    })));
  };

  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    className: "menu-header",
    style: {
      display: 'flex'
    }
  }, state.previous.length > 0 && /*#__PURE__*/React.createElement("button", {
    className: "back",
    onClick: function onClick() {
      return dispatch({
        type: 'back'
      });
    }
  }, "Back"), /*#__PURE__*/React.createElement("div", {
    className: "menu-title"
  }, state.active.title)), /*#__PURE__*/React.createElement("div", {
    className: "menu-container",
    style: {
      position: 'relative',
      height: 600
    }
  }, /*#__PURE__*/React.createElement(Menu, {
    menu: menus
  })));
};

var MenuShape = {
  title: PropTypes.string,
  id: PropTypes.string
};
var ItemsShape = {
  text: PropTypes.string.isRequired,
  link: PropTypes.string
};
ItemsShape.menu = PropTypes.shape(MenuShape);
MenuShape.items = PropTypes.arrayOf(PropTypes.shape(ItemsShape));
NestedNav.propTypes = {
  menus: PropTypes.shape(MenuShape)
};

export { NestedNav };
//# sourceMappingURL=index.modern.js.map
